@@ -61,7 +61,7 @@ QualifiedIdentifier InstantiationInformation::applyToIdentifier(const QualifiedI
 }
 
 void InstantiationInformation::addTemplateParameter(KDevelop::AbstractType::Ptr type) {
-  templateParametersList().append(type->indexed());
+  templateParametersList().append(IndexedType(type));
 }
 
 QString InstantiationInformation::toString(bool local) const {
@@ -121,15 +121,15 @@ static KDevelop::RepositoryManager<KDevelop::ItemRepository<InstantiationInforma
     return instantiationInformationRepositoryObject;
 }
 
-void initInstantiationInformationRepository() {
-  instantiationInformationRepository();
-}
-
 uint standardInstantiationInformationIndex() {
   static uint idx = instantiationInformationRepository()->index( InstantiationInformation() );
   return idx;
 }
 
+void initInstantiationInformationRepository() {
+  standardInstantiationInformationIndex();
+}
+
 IndexedInstantiationInformation::IndexedInstantiationInformation() : m_index(0) {
 }
 
