@@ -36,8 +36,8 @@ namespace KDevelop
  */
 class KDEVPLATFORMLANGUAGE_EXPORT IndexedType : public ReferenceCountManager {
   public:
-    /// Constructor.
     IndexedType(const IndexedType& rhs);
+    explicit IndexedType(const AbstractType::Ptr& type);
     explicit IndexedType(uint index = 0);
     
     ~IndexedType();
@@ -100,6 +100,11 @@ class KDEVPLATFORMLANGUAGE_EXPORT IndexedType : public ReferenceCountManager {
     uint m_index;
 };
 
+inline uint qHash(const IndexedType& type)
+{
+  return type.hash();
+}
+
 }
 
 Q_DECLARE_TYPEINFO(KDevelop::IndexedType, Q_MOVABLE_TYPE);
