@@ -117,6 +117,8 @@ const QVector<Indicator> INDICATORS {
 const QVector<ErrorFormat> ERROR_FILTERS {
     // GCC - another case, eg. for #include "pixmap.xpm" which does not exists
     ErrorFormat( "^([^:\t]+):([0-9]+):([0-9]+):([^0-9]+)", 1, 2, 4, 3 ),
+    // ant
+    ErrorFormat("\\[javac\\][\\s]+([^:\t]+):([0-9]+): (warning: .*|error: .*)", 1, 2, 3, "javac"),
     // GCC
     ErrorFormat( "^([^:\t]+):([0-9]+):([^0-9]+)", 1, 2, 3 ),
     // GCC
@@ -381,6 +383,9 @@ FilteredItem ScriptErrorFilterStrategy::errorInLine(const QString& line)
 /// --- Native application error filter strategy ---
 
 const QList<ErrorFormat> QT_APPLICATION_ERROR_FILTERS = QList<ErrorFormat>()
+    // QObject::connect related errors, also see err_method_notfound() in qobject.cpp
+    // QObject::connect: No such slot Foo::bar() in /foo/bar.cpp:313
+    << ErrorFormat("^QObject::connect: (?:No such|Parentheses expected,) (?:slot|signal) [^ ]* in (.*):([0-9]+)$", 1, 2, -1)
     // ASSERT: "errors().isEmpty()" in file /foo/bar.cpp, line 49
     << ErrorFormat("^ASSERT: \"(.*)\" in file (.*), line ([0-9]+)$", 2, 3, -1)
     // QFATAL : FooTest::testBar() ASSERT: "index.isValid()" in file /foo/bar.cpp, line 32
