@@ -48,9 +48,8 @@ namespace KDevelop
 class KDEVPLATFORMTESTS_EXPORT AutoTestShell : public KDevelop::ShellExtension
 {
 public:
-    AutoTestShell(const QStringList& plugins)
-        : m_plugins(plugins)
-    {}
+    AutoTestShell(const QStringList& plugins);
+
     QString xmlFile() { return QString(); }
     virtual QString binaryPath() { return QString(); };
     QString defaultProfile() { return "kdevtest"; }
@@ -70,10 +69,7 @@ public:
      * @p plugins A list of default global plugins which should be loaded.
      *            By default, all global plugins are loaded.
      */
-    static void init(const QStringList& plugins = QStringList())
-    {
-        s_instance = new AutoTestShell(plugins);
-    }
+    static void init(const QStringList& plugins = QStringList());
 
 private:
     QStringList m_plugins;
